==> opencensus-python-0.8.0-gh.tar.gz: opencensus-python-0.8.0/contrib/opencensus-ext-django/CHANGELOG.md <==
# Changelog

## Unreleased

## 0.7.5
Released 2021-05-13

- Add exception tracing to django middleware
([#885](https://github.com/census-instrumentation/opencensus-python/pull/885))

## 0.7.4
Released 2021-01-19

- Hotfix
([#999](https://github.com/census-instrumentation/opencensus-python/pull/999))

## 0.7.3
Released 2021-01-14

- Change blacklist to excludelist
([#977](https://github.com/census-instrumentation/opencensus-python/pull/977))

## 0.7.2
Released 2019-09-30

- Use Django 2.0 DB instrumentation
([#775](https://github.com/census-instrumentation/opencensus-python/pull/775))

## 0.7.1
Released 2019-08-26

- Updated `http.status_code` attribute to be an int.
  ([#755](https://github.com/census-instrumentation/opencensus-python/pull/755))

## 0.7.0
Released 2019-07-31

- Updated span attributes to include some missing attributes listed
  [here](https://github.com/census-instrumentation/opencensus-specs/blob/master/trace/HTTP.md#attributes)
  ([#735](https://github.com/census-instrumentation/opencensus-python/pull/735))

## 0.3.2
Released 2019-07-26

- Removed support for Django < 1.11
  ([#694](https://github.com/census-instrumentation/opencensus-python/pull/694))
- Allow installing with Django 2.0 and later
  ([#697](https://github.com/census-instrumentation/opencensus-python/pull/697))

## 0.3.1
Released 2019-06-04

- Make ProbabilitySampler default

## 0.3.0
Released 2019-04-24

- Decoupled exporter specific logic from configuration
- Prevent anonymous user error on old django versions
  ([#603](https://github.com/census-instrumentation/opencensus-python/pull/603))

## 0.2.0
Released 2019-04-08

- Update for package changes in core library

## 0.1.0
Released 2019-03-19

- Initial version

==> opencensus-python-0.11.4-1.1.13-gh.tar.gz: opencensus-python-0.11.4-1.1.13/contrib/opencensus-ext-django/CHANGELOG.md <==
# Changelog

## Unreleased

## 0.8.0
Released 2022-10-17

- Fixed support for Django 4.1
- ([#1159](https://github.com/census-instrumentation/opencensus-python/pull/1159))

## 0.7.5
Released 2021-05-13

- Add exception tracing to django middleware
([#885](https://github.com/census-instrumentation/opencensus-python/pull/885))

## 0.7.4
Released 2021-01-19

- Hotfix
([#999](https://github.com/census-instrumentation/opencensus-python/pull/999))

## 0.7.3
Released 2021-01-14

- Change blacklist to excludelist
([#977](https://github.com/census-instrumentation/opencensus-python/pull/977))

## 0.7.2
Released 2019-09-30

- Use Django 2.0 DB instrumentation
([#775](https://github.com/census-instrumentation/opencensus-python/pull/775))

## 0.7.1
Released 2019-08-26

- Updated `http.status_code` attribute to be an int.
  ([#755](https://github.com/census-instrumentation/opencensus-python/pull/755))

## 0.7.0
Released 2019-07-31

- Updated span attributes to include some missing attributes listed
  [here](https://github.com/census-instrumentation/opencensus-specs/blob/master/trace/HTTP.md#attributes)
  ([#735](https://github.com/census-instrumentation/opencensus-python/pull/735))

## 0.3.2
Released 2019-07-26

- Removed support for Django < 1.11
  ([#694](https://github.com/census-instrumentation/opencensus-python/pull/694))
- Allow installing with Django 2.0 and later
  ([#697](https://github.com/census-instrumentation/opencensus-python/pull/697))

## 0.3.1
Released 2019-06-04

- Make ProbabilitySampler default

## 0.3.0
Released 2019-04-24

- Decoupled exporter specific logic from configuration
- Prevent anonymous user error on old django versions
  ([#603](https://github.com/census-instrumentation/opencensus-python/pull/603))

## 0.2.0
Released 2019-04-08

- Update for package changes in core library

## 0.1.0
Released 2019-03-19

- Initial version
